Discover Packages
github.com/Nishanth1812/devpulse
internal
models
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Aug 14, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type CollectOptions struct {
MaxCommits int
Since *time .Time
IncludeDiff bool
FullDiffCommits int
}
type CommitSummary struct {
SHA string `json:"sha"`
Message string `json:"message"`
Author string `json:"author"`
Timestamp time .Time `json:"timestamp"`
FilesChanged []string `json:"files_changed"`
DiffSnippet string `json:"diff_snippet"`
}
type Deadline struct {
Date time .Time `json:"date"`
Description string `json:"description"`
DaysUntil int `json:"days_until"`
}
type GoalsData struct {
Now string `json:"now"`
Next string `json:"next"`
Deadlines []Deadline `json:"deadlines"`
Someday string `json:"someday"`
}
type RegisteredRepo struct {
Name string `json:"name"`
Path string `json:"path"`
}
RegisteredRepo represents a named repository registered with DevPulse.
type RepoData struct {
Name string `json:"name"`
Path string `json:"path"`
Branch string `json:"branch"`
HeadSHA string `json:"head_sha"`
Commits []CommitSummary `json:"commits"`
PlanSummary string `json:"plan_summary"`
Notes string `json:"notes"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.